@@ -1,28 +1,30 @@
 from os import path
 
+import beangulp
 import blockcypher
 import yaml
 from beancount.core import amount, data
 from beancount.core.number import D
-from beancount.ingest import importer
 
+from tariochbctools.importers.general.deduplication import ReferenceDuplicatesComparator
 from tariochbctools.importers.general.priceLookup import PriceLookup
 
 
-class Importer(importer.ImporterProtocol):
+class Importer(beangulp.Importer):
     """An importer for Blockchain data."""
 
-    def identify(self, file):
-        return "blockchain.yaml" == path.basename(file.name)
+    def identify(self, filepath: str) -> bool:
+        return path.basename(filepath).endswith("blockchain.yaml")
 
-    def file_account(self, file):
+    def account(self, filepath: str) -> data.Entries:
         return ""
 
-    def extract(self, file, existing_entries):
-        config = yaml.safe_load(file.contents())
+    def extract(self, filepath: str, existing: data.Entries) -> data.Entries:
+        with open(filepath) as file:
+            config = yaml.safe_load(file)
         self.config = config
         baseCcy = config["base_ccy"]
-        priceLookup = PriceLookup(existing_entries, baseCcy)
+        priceLookup = PriceLookup(existing, baseCcy)
 
         entries = []
         for address in self.config["addresses"]:
@@ -38,9 +40,9 @@ class Importer(importer.ImporterProtocol):
 
                 date = trx["confirmed"].date()
                 price = priceLookup.fetchPriceAmount(currency, date)
-                cost = data.Cost(price, baseCcy, None, None)
+                cost = data.CostSpec(price, None, baseCcy, None, None, False)
 
-                outputType = "eth" if currency.lower() == "eth" else "btc"
+                outputType = "ether" if currency.lower() == "eth" else "btc"
                 amt = blockcypher.from_base_unit(trx["value"], outputType)
 
                 entry = data.Transaction(
@@ -65,3 +67,5 @@ class Importer(importer.ImporterProtocol):
                 entries.append(entry)
 
         return entries
+
+    cmp = ReferenceDuplicatesComparator()
