@@ -1,30 +1,32 @@
 import csv
-from io import StringIO
+import re
 
+import beangulp
 from beancount.core import amount, data
 from beancount.core.number import D
-from beancount.ingest import importer
-from beancount.ingest.importers.mixins import identifier
 from dateutil.parser import parse
 
 
-class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
+class Importer(beangulp.Importer):
     """An importer for Neon CSV files."""
 
-    def __init__(self, regexps, account):
-        identifier.IdentifyMixin.__init__(self, matchers=[("filename", regexps)])
-        self.account = account
+    def __init__(self, filepattern: str, account: data.Account):
+        self._filepattern = filepattern
+        self._account = account
 
-    def name(self):
-        return super().name() + self.account
+    def identify(self, filepath: str) -> bool:
+        return re.search(self._filepattern, filepath) is not None
 
-    def file_account(self, file):
-        return self.account
+    def name(self) -> str:
+        return super().name() + self._account
 
-    def extract(self, file, existing_entries):
+    def account(self, filepath: str) -> data.Account:
+        return self._account
+
+    def extract(self, filepath: str, existing: data.Entries) -> data.Entries:
         entries = []
 
-        with StringIO(file.contents()) as csvfile:
+        with open(filepath) as csvfile:
             reader = csv.DictReader(
                 csvfile,
                 [
@@ -55,7 +57,7 @@ class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
                     metakv["original_amount"] = row["Original amount"]
                     metakv["exchange_rate"] = row["Exchange rate"]
 
-                meta = data.new_metadata(file.name, 0, metakv)
+                meta = data.new_metadata(filepath, 0, metakv)
                 description = row["Description"].strip()
                 if row["Subject"].strip() != "":
                     description = description + ": " + row["Subject"].strip()
@@ -69,7 +71,7 @@ class Importer(identifier.IdentifyMixin, importer.ImporterProtocol):
                     data.EMPTY_SET,
                     data.EMPTY_SET,
                     [
-                        data.Posting(self.account, amt, None, None, None, None),
+                        data.Posting(self._account, amt, None, None, None, None),
                     ],
                 )
                 entries.append(entry)
