@@ -1,23 +1,24 @@
 import argparse
 import sys
+from typing import Any
 
 import requests
 
 
-def build_header(token):
+def build_header(token: str) -> dict[str, str]:
     return {"Authorization": "Bearer " + token}
 
 
-def check_result(result):
+def check_result(result: requests.Response) -> None:
     try:
         result.raise_for_status()
     except requests.exceptions.HTTPError as e:
         raise Exception(e, e.response.text)
 
 
-def get_token(secret_id, secret_key):
+def get_token(secret_id: str, secret_key: str) -> str:
     r = requests.post(
-        "https://ob.nordigen.com/api/v2/token/new/",
+        "https://bankaccountdata.gocardless.com/api/v2/token/new/",
         data={
             "secret_id": secret_id,
             "secret_key": secret_key,
@@ -28,9 +29,9 @@ def get_token(secret_id, secret_key):
     return r.json()["access"]
 
 
-def list_bank(token, country):
+def list_bank(token: str, country: str) -> None:
     r = requests.get(
-        "https://ob.nordigen.com/api/v2/institutions/",
+        "https://bankaccountdata.gocardless.com/api/v2/institutions/",
         params={"country": country},
         headers=build_header(token),
     )
@@ -40,7 +41,7 @@ def list_bank(token, country):
         print(asp["name"] + ": " + asp["id"])  # noqa: T201
 
 
-def create_link(token, reference, bank):
+def create_link(token: str, reference: str, bank: str) -> None:
     if not bank:
         raise Exception("Please specify --bank it is required for create_link")
     requisitionId = _find_requisition_id(token, reference)
@@ -48,7 +49,7 @@ def create_link(token, reference, bank):
         print(f"Link for for reference {reference} already exists.")  # noqa: T201
     else:
         r = requests.post(
-            "https://ob.nordigen.com/api/v2/requisitions/",
+            "https://bankaccountdata.gocardless.com/api/v2/requisitions/",
             data={
                 "redirect": "http://localhost",
                 "institution_id": bank,
@@ -61,9 +62,11 @@ def create_link(token, reference, bank):
         print(f"Go to {link} for connecting to your bank.")  # noqa: T201
 
 
-def list_accounts(token):
+def list_accounts(token: str) -> None:
     headers = build_header(token)
-    r = requests.get("https://ob.nordigen.com/api/v2/requisitions/", headers=headers)
+    r = requests.get(
+        "https://bankaccountdata.gocardless.com/api/v2/requisitions/", headers=headers
+    )
     print(r.json())  # noqa: T201
     check_result(r)
     for req in r.json()["results"]:
@@ -71,7 +74,8 @@ def list_accounts(token):
         print(f"Reference: {reference}")  # noqa: T201
         for account in req["accounts"]:
             ra = requests.get(
-                f"https://ob.nordigen.com/api/v2/accounts/{account}", headers=headers
+                f"https://bankaccountdata.gocardless.com/api/v2/accounts/{account}",
+                headers=headers,
             )
             check_result(ra)
             acc = ra.json()
@@ -79,7 +83,7 @@ def list_accounts(token):
             iban = acc["iban"]
 
             ra = requests.get(
-                f"https://ob.nordigen.com/api/v2/accounts/{account}/details",
+                f"https://bankaccountdata.gocardless.com/api/v2/accounts/{account}/details",
                 headers=headers,
             )
             check_result(ra)
@@ -90,19 +94,21 @@ def list_accounts(token):
             print(f"{account}: {asp} {owner} {iban} {currency}")  # noqa: T201
 
 
-def delete_link(token, reference):
+def delete_link(token: str, reference: str) -> None:
     requisitionId = _find_requisition_id(token, reference)
     if requisitionId:
         r = requests.delete(
-            f"https://ob.nordigen.com/api/v2/requisitions/{requisitionId}",
+            f"https://bankaccountdata.gocardless.com/api/v2/requisitions/{requisitionId}",
             headers=build_header(token),
         )
         check_result(r)
 
 
-def _find_requisition_id(token, userId):
+def _find_requisition_id(token: str, userId: str) -> str | None:
     headers = build_header(token)
-    r = requests.get("https://ob.nordigen.com/api/v2/requisitions/", headers=headers)
+    r = requests.get(
+        "https://bankaccountdata.gocardless.com/api/v2/requisitions/", headers=headers
+    )
     check_result(r)
     for req in r.json()["results"]:
         if req["reference"] == userId:
@@ -111,7 +117,7 @@ def _find_requisition_id(token, userId):
     return None
 
 
-def parse_args(args):
+def parse_args(args: Any) -> Any:
     parser = argparse.ArgumentParser(description="nordigen-config")
     parser.add_argument(
         "--secret_id",
@@ -149,7 +155,7 @@ def parse_args(args):
     return parser.parse_args(args)
 
 
-def main(args):
+def main(args: Any) -> None:
     args = parse_args(args)
 
     token = get_token(args.secret_id, args.secret_key)
@@ -164,6 +170,6 @@ def main(args):
         delete_link(token, args.reference)
 
 
-def run():
+def run() -> None:
     """Entry point for console_scripts"""
     main(sys.argv[1:])
